	SUBROUTINE CPB_FRQ ( mxt, mxd, ndpth, npts, itrc, dtrace, rmiss,
     +			     nrisk, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_FRQ								*
C*									*
C* This subroutine computes the frequency at which the threshold is	*
C* exceeded for a given risk category.					*
C*									*
C* The result is the ratio of the number of occurrences of the event	*
C* that the threshold is exceeded for a given forecast risk to the	*
C* total number of events in that risk category.			*
C*									*
C* The risk category is denoted by the number NRISK.  The first risk	*
C* category (usually no risk) is denoted by 1, and so on.		*
C*									*
C* The trace data begins with the total number of events, followed by	*
C* the fraction of that number falling within the risk categories in	*
C* order of ascending risk, starting with the second risk category.	*
C* The entries following those are the fractions of the total count	*
C* for each risk category that were accompanied by the occurrence of 	*
C* the event.  For this set of fractions, the first risk category is	*
C* included.								*
C*									*
C* CPB_FRQ ( MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, NRISK,		*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	NRISK		INTEGER		Risk number			*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -2 = invalid risk category	*
C**									*
C* Log:									*
C* K. Brill/HPC		 8/00						*
C* K. Brill/HPC		 9/00	Check for division by zero		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		rk, fo, ff
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	krsk = ndpth / 2
	IF ( nrisk .le. 0 .or. nrisk .gt. krsk ) THEN
	    iret = -2
	    RETURN
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    rk  = dtrace (itrc,1,ip)
	    IF ( ok .and. rk .gt. 0 ) THEN
		IF ( nrisk .eq. 1 ) THEN
		    ff = rk
		    DO i = 2, krsk
			ff = ff - dtrace (itrc,i,ip)
		    END DO
		ELSE
		    ff = dtrace (itrc,nrisk,ip)
		END IF
		IF ( ff .le. 0.0 ) THEN
		    trcdat (ip) = rmiss
		ELSE
		    indx = krsk + nrisk
		    fo = dtrace (itrc,indx,ip)
		    td = fo / ff
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
