	SUBROUTINE CPB_SCR ( iscor, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			     rmiss,
     +			     prbs, nprbs, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_SCR								*
C*									*
C* This subroutine computes either the actual Brier score or the	*
C* optimal/target B score.  The latter score represents the best that	*
C* could be achieved if the probabilities of observations exceeding	*
C* the thresholds in each risk category are actually observed.		*
C*									*
C* The Brier score for events with two outcomes (< threshold and >=	*
C* threshold) and forecast probabilities fixed for designated		*
C* categories is given by:						*
C*									*
C*       PBS = SUM [ n(r) * ( f(r)**2 - 2*f(r)*p(r) + p(r) ) ]		*
C*									*
C* where n(r) is the number of events in category r divided by the	*
C* total number of events over all categories, p(r) is the number of	*
C* events in category r observed to exceed the threshold divided by	*
C* the total number of events in category r, f(r) is the forecast	*
C* probability of exceeding the threshold associated with the risk	*
C* category r, and the summation is over risk categories, r.		*
C*									*
C* The target PB score is defined as follows:				*
C*									*
C*	     TBS = SUM [ n(r) * ( f(r) - f(r)**2 ) ]			*
C*									*
C* where the symbols are as defined above and the summation is over	*
C* risk categories, r.							*
C*									*
C* PBS is computed when ISCOR = 0 and TBS is computed otherwise.	*
C*									*
C* The trace data begins with the total number of events, followed by	*
C* the fraction of that number falling within the risk categories in	*
C* order of ascending risk, starting with the second risk category.	*
C* The entries following those are the fractions of the total count	*
C* for each risk category that were accompanied by the occurrence of 	*
C* the event.  For this set of fractions, the first risk category is	*
C* included.								*
C*									*
C* CPB_SCR ( ISCOR, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE,		*
C*	     RMISS, PRBS, NPRBS, TRCDAT, TRCMIN, TRCMAX, IRET )		*
C*									*
C* Input parameters:							*
C*	ISCOR		INTEGRE		Score type			*
C*					  0 = actual Brier score	*
C*					  1 = best possible score	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	PRBS (NPRBS)	REAL		Forcast probabilities		*
C*	NPRBS		INTEGER		# of probabilities 		*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = Computation not possible	*
C**									*
C* Log:									*
C* K. Brill/HPC		 8/00						*
C* K. Brill/HPC		 9/00	Completely reworked			*
C* K. Brill/HPC		 5/02	Remove factor of 2 so score ranges 0 - 1*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL		prbs (*)
C*
	REAL*8		rnttl, rnc, pr, nr, fr, sum
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	nrisk = ndpth / 2
	IF ( nprbs .ne. nrisk ) THEN
	    iret = -1
	    RETURN
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    rnttl  = dtrace (itrc,1,ip)
	    IF ( ok .and. rnttl .gt. 0.0 ) THEN
	        icntz = 0
		sum = 0.0
		DO irisk = 1, nrisk
		    IF ( irisk .eq. 1 ) THEN
			rnc = rnttl
			DO i = 2, nrisk
			    rnc = rnc - dtrace (itrc,i,ip)
			END DO
		    ELSE
			rnc = dtrace (itrc,irisk,ip)
		    END IF
		    nr = rnc / rnttl
		    fr = prbs (irisk)
		    IF ( iscor .eq. 0 ) THEN
			IF ( rnc .le. 0.0 ) THEN
			    icntz = icntz + 1
			ELSE
			    indx = nrisk + irisk
			    pr = dtrace (itrc,indx,ip) / rnc
			    sum = sum +
     +				nr * ( fr * fr - 2. * fr * pr + pr )
			END IF
		    ELSE
			IF ( nr .le. 0 ) THEN
			    icntz = icntz + 1
			ELSE
			    sum = sum + nr * ( fr - fr * fr )
			END IF
		    END IF
		END DO
		IF ( icntz .eq. nrisk ) THEN
		    trcdat (ip) = rmiss
		ELSE
C
C*		    The target score is not well defined unless all
C*		    n(r) > 0; so, set it to the optimum Brier score
C*		    in that case.
C
		    IF ( icntz .gt. 0 .and. iscor .ne. 0 ) sum = 0.0
C*
		    trcdat (ip) = sum
C*
		    IF ( trcdat (ip) .lt. trcmin ) trcmin = trcdat (ip)
		    IF ( trcdat (ip) .gt. trcmax ) trcmax = trcdat (ip)
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
