	SUBROUTINE CPB_SUMS ( mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, icat, trcdat, trcmin, trcmax,
     +			      iret )
C************************************************************************
C* CPB_SUMS								*
C*									*
C* This subroutine computes the sums of data counts.  If ICAT = 1, the	*
C* sum is the total number of observations in forecast risk regions;	*
C* if ICAT = 2,	the sum is the total number of observations exceeding	*
C* the threshold.							*
C*									*
C* CPB_SUMS ( MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, ICAT,		*
C*	      TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	ICAT		INTEGER		Sum category flag:		*
C*					   1 = sum over risk categories	*
C*					   2 = sum over obs > threshold *
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		07/01						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		td
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	IF ( icat .le. 1 ) THEN
	    mstrt = 2
	    mstop = ndpth / 2
	ELSE
	    mstrt = ndpth / 2 + 1
	    mstop = ndpth
	END IF
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
		td = 0.0
		DO m = mstrt, mstop
	    	    td = td + dtrace (itrc,m,ip)
		END DO
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
