	SUBROUTINE CPB_TSSK ( indx, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, icat, trcdat, trcmin, trcmax,
     +			      iret )
C************************************************************************
C* CPB_TSSK								*
C*									*
C* This subroutine computes the Threat score, Heidke skill score,	*
C* Peirce-Hanssen-Kuipers discriminant skill score, the standard error	*
C* of LN (odds ratio), the odds ratio, the odds ratio skill score, 	*
C* LN (odds ratio), or odds ratio skill score cubed from PBS values.	*
C*									*
C* A value that exceeds the threshold is counted as a hit if it is	*
C* within the category selected by ICAT or any higher category.  If	*
C* ICAT <= 0, all categories except the no risk category are used.	*
C* ICAT <= 0 produces the same result as ICAT = 1.			*
C*									*
C* Only values within category ICAT and higher categories are counted	*
C* as forecasts.  All values exceeding the threshold are counted as	*
C* observations.							*
C*									*
C* CPB_TSSK ( INDX, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, ICAT,	*
C*	      TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Calculation selection #:	*
C*					0 = Threat score		*
C*					1 = Heidke Skill Score		*
C*					2 = P-H-K Skill Score		*
C*					3 = Std error of LN (Odds Ratio)*
C*					4 = Odds Ratio			*
C*					5 = Odds Ratio Skill Score, ORSS*
C*					6 = LN (Odds Ratio)		*
C*					7 = ORSS ** 3			*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	ICAT		INTEGER		Detection category cutoff	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		12/00						*
C* K. Brill/HPC		10/02	Add calculations 1--6.			*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, td, dn, tn
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	mcat = icat
	IF ( mcat .le. 0 ) mcat = 1
	IF ( mcat .gt. (ndpth/2-1) ) mcat = ndpth/2 - 1
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
		f = 0.0
		nsplt = ndpth / 2
		DO m = mcat+1, nsplt
	    	    f = f + dtrace (itrc,m,ip)
		END DO
		h = 0.0
		DO m = ndpth, nsplt+1+mcat, -1
		    h = h + dtrace (itrc,m,ip)
		END DO
		o = h
		DO m = nsplt+1, nsplt+mcat
		    o = o + dtrace (itrc,m,ip)
		END DO
		tn = dtrace (itrc,1,ip)
		IF ( indx .eq. 0 ) THEN
C
C*		    Compute threat score.
C
		    dn = o + f - h
		    IF ( dn .ne. 0.0 ) THEN
			td = h / dn
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 1 ) THEN
C
C*		    Compute Heidke skill score.
C
		    dn = tn * ( o + f ) - 2. * o * f
		    IF ( dn .ne. 0.0 ) THEN
			td = 2. * ( tn * h - f * o ) / dn
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 2 ) THEN
C
C*		    Compute the P-H-K skill score.
C
		    dn = o * ( tn - o )
		    IF ( dn .ne. 0.0 ) THEN
			td = ( tn * h - f * o ) / dn
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 3 .and. h .gt. 5. ) THEN
C
C*		    Compute standard error (deviation) of Odds Ratio.
C
		    IF ( f .gt. h .and. o .gt. h  .and. tn+h .gt. f+o )
     +			THEN
			td = 1./h + 1./(f-h) + 1./(o-h) + 1/(tn-f-o+h)
			td = SQRT ( td )
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .ge. 4 ) THEN
C
C*		    Compute the Odds Ratio.
C
		    dn = ( f - h ) * ( o - h )
		    IF ( dn .ne. 0.0 ) THEN
			td = h * ( tn -f - o + h )
			td = td / dn
			IF ( indx .eq. 4 ) THEN
C
C*			    Odds ratio is td.
C
			ELSE IF ( indx .eq. 5 .or. indx .eq. 7 ) THEN
C
C*			    Compute Odds Ratio skill score.
C
			    td = ( td - 1 ) / ( td + 1 )
C
C*			    Compute Odds Ratio skill score cubed.
C
			    IF ( indx .eq. 7 ) td = td * td * td
			ELSE IF ( indx .eq. 6 .and. td .gt. 0.0 ) THEN
C
C*			    Compute LN (Odds Ratio).
C
			    td = DLOG (td)
			ELSE
			    td = rmiss
			END IF
		    ELSE
			td = rmiss
		    END IF
		ELSE
		    td = rmiss
		END IF
		IF ( td .ne. rmiss ) THEN
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
