	SUBROUTINE CS_ACCM ( iacm, trcd, npts, rmiss, cxpts, trcdat,
     +			     trcmin, trcmax, iret )
C************************************************************************
C* CS_ACCM								*
C*									*
C* This subroutine computes the cumulative or absolute % contribution	*
C* of each threshold range to the total precipitation accumulation.	*
C*									*
C* If IACM > 0, then the cumulative % is computed; otherwise, the 	*
C* absolute % at each point is computed.  If IACM = 1, the cumulative	*
C* % is computed from low to high threshold; while, if IACM = 2, the	*
C* cumulative % is computed from high to low threshold.			*
C*									*
C* For every threshold interval (except the last) the geometric mean	*
C* of the two bounding accumulation values multiplied by the		*
C* incremental number of points from the next higher threshold is used	*
C* to represent the volume for the interval.  The last interval is 	*
C* open ended, so the two accumulation values used for the geometric	*
C* mean are the last threshold and that value plus the increment	*
C* between it and the penultimate threshold value.			*
C*									*
C* CS_ACCM ( IACM, TRCD, NPTS, RMISS, CXPTS, TRCDAT, TRCMIN, TRCMAX,	*
C*	     IRET )							*
C*									*
C* Input parameters:							*
C*	IACM		INTEGER		Flag for cumulative %		*
C*	TRCD (NPTS)	REAL*8		Trace data input		*
C*	NPTS		INTEGER		Number of trace points		*
C*	RMISS		REAL		Missing value for output	*
C*	CXPTS (NPTS)	CHAR*		Input threshold ranges		*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/00						*
C* K. Brill/HPC		 3/01	Use last threshold plus last interval	*
C*				for geometric mean; add IACM=2 option	*
C************************************************************************
	REAL*8		trcd (*), trcdat (*)
	CHARACTER*(*)	cxpts (*)
C*
	REAL*8		ttlvol, amt
	REAL		xpts (2)
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	ttlvol = 0.
	READ (cxpts(1),*,IOSTAT=ios) xpts (1)
	IF ( ios .ne. 0 ) xpts (1) = 0.0
	DO ip = 1, npts-1
	    READ (cxpts(ip+1),*,IOSTAT=ios) xpts (2)
	    IF ( ios .ne. 0 ) xpts (2) = 0.0
	    IF ( trcd (ip)  .gt. -1.E30 ) THEN
		amt = SQRT ( xpts (1) * xpts (2) )
		trcdat (ip) = ( trcd (ip) - trcd (ip+1) ) * amt
		ttlvol = ttlvol + trcdat (ip)
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	    diff = xpts (2) - xpts (1)
	    xpts (1) = xpts (2)
	END DO
	IF ( trcd (npts) .gt. -1.E30 ) THEN
	    xpp = xpts (1) + diff
	    amt = SQRT ( xpts (1) * xpp )
	    trcdat (npts) = trcd (npts) * amt
	    ttlvol = ttlvol + trcdat (npts)
	ELSE
	    trcdat (npts) = rmiss
	END IF
	DO ip =1, npts
	    IF ( trcd (ip) .gt. -1.E30 .and. ttlvol .gt. 0.0 ) THEN
		trcdat (ip) = trcdat (ip) * 100. / ttlvol
		IF ( iacm .gt. 0 .and. ip .gt. 1 ) THEN
		    trcdat (ip) = trcdat (ip-1) +
     +					trcdat (ip)
		END IF
		IF ( trcdat (ip) .gt. trcmax )
     +			trcmax = trcdat (ip)
		IF ( trcdat (ip) .lt. trcmin )
     +			trcmin = trcdat (ip)
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
	IF ( iacm .eq. 2 ) THEN
	    DO ip =1, npts
		IF ( trcdat (ip) .ne. rmiss ) THEN
		    trcdat (ip) = 1.0 - trcdat (ip)
		    IF ( trcdat (ip) .gt. trcmax )
     +			trcmax = trcdat (ip)
		    IF ( trcdat (ip) .lt. trcmin )
     +			trcmin = trcdat (ip)
		END IF
	    END DO
	END IF
C*
	RETURN
	END
