	SUBROUTINE CS_ORSK ( indx, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_ORSK								*
C*									*
C* This subroutine computes the Odds Ratio (OR), Odds Ratio Skill	*
C* Score (ORSS), LN (OR), standard deviation (standard error) of the	*
C* LN(OR) (SELNOR), ORSS**3 from FHO values, the LN(OR) / (standard	*
C* error), or the integral between the ROC curve implied by OR and the	*
C* diagonal, which is the ROC curve for a random forecast.		*
C*									*
C* CS_ORSK ( INDX, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Calculation selection #:	*
C*					0 = Odds ratio (OR)		*
C*					1 = Odds ratio skill scr (ORSS) *
C*					2 = LN (OR)			*
C*					3 = standard error of 2 (SELNOR)*
C*					4 = ORSS ** 3			*
C*					5 = LN(OR) / SELNOR		*
C*					6 = OR ROC curve area - chance	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		10/02						*
C* K. Brill/HPC		 3/03	Add option 5--LN(OR)/SELNOR		*
C* K. Brill/HPC		 4/03	Documentation for SELNOR		*
C* K. Brill/HPC		 8/03	Add option 6--area btwn ROC curve & /	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		tn, f, h, o, td, dn
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +           tn .ne. 0.0 ) THEN
		IF ( indx .ne. 3 .and. indx .ne. 5 ) THEN
		    td = h * ( tn - f - o + h )
		    dn = ( o - h ) * ( f - h )
		    IF ( dn .ne. 0.0 ) THEN
			td = td / dn
			IF ( indx .eq. 0 ) THEN
C
C*			    Odds ratio is td.
C
			ELSE IF ( indx .eq. 1 .or. indx .eq. 4 ) THEN
C
C*			    Compute odds ratio skill score.
C
			    td = ( td - 1 ) / ( td + 1 )
C
C*			    Compute odds ratio skill score cubed.
C
			    IF ( indx .eq. 4 ) td = td * td * td
			ELSE IF ( indx .eq. 2 .and. td .gt. 0. ) THEN
C
C*			    Compute log of odds ratio.
C
			    td = DLOG ( td )
			ELSE IF ( ( indx .eq. 6 .and. td .gt. 1. ) .or.
     +				  ( indx .eq. 6 .and. ( td .gt. 0.0
     +                              .and. td .lt. 1. ) ) ) THEN
C
C*			    Compute area between ROC curve and diagonal.
C
			    dn = td - 1.
			    td = ( td / dn ) *
     +				 ( 1. - ( DLOG (td) / dn ) )
			    td = td - .5
			ELSE IF ( indx .eq. 6 .and. td .eq. 1. ) THEN
C
C*			    Area between ROC curve and diagonal is 0.
C
			    td = 0.0
			ELSE
			    td = rmiss
			END IF
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 3 .and. h .gt. 5. .and.
     +			  o .gt. h .and. f .gt. h .and.
     +			  (tn+h) .gt. (f+o) ) THEN
C
C*		    Compute standard error of LN(OR).
C
		    td = 1./h + 1./(f-h) + 1./(o-h) + 1./(tn-f-o+h)
		    td = SQRT ( td )
		ELSE IF ( indx .eq. 5 .and. h .gt. 5. .and.
     +			  o .gt. h .and. f .gt. h .and.
     +			  (tn+h) .gt. (f+o) ) THEN
		    td = h * ( tn - f - o + h )
		    dn = ( o - h ) * ( f - h )
		    IF ( dn .ne. 0.0 ) THEN
			td = td / dn
C
C*			Compute log of odds ratio.
C
			IF ( td .gt. 0.0 ) THEN
			    td = DLOG ( td )
			ELSE
			    td = rmiss
			END IF
C
C*			Compute standard error of LN(OR).
C
			dn = 1./h + 1./(f-h) + 1./(o-h) + 1./(tn-f-o+h)
C
C*			Compute # of standard deviations from zero.
C
			IF ( dn .gt. 0.0 .and. td .ne. rmiss ) THEN
		            td = td / SQRT ( dn )
			ELSE
			    td = rmiss
			END IF
		    ELSE
			td = rmiss
		    END IF
		ELSE
		    td = rmiss
		END IF
		IF ( td .ne. rmiss ) THEN
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
