	SUBROUTINE RDTD_BAJ ( itrc, iba, banam, iret )
C************************************************************************
C* RDTD_BAJ								*
C*									*
C* This subroutine performs bias adjustment for FHO values.		*
C*									*
C* If the bias adjustment has changed, the trace data is re-initiaized.	*
C*									*
C* RDTD_BAJ ( ITRC, IBA, BANAM, IRET )					*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number			*
C*	IBA		INTEGER		Bias adjustment prefix #	*
C*					  0 = No bias adjustment	*
C*					101 = DH/DF based adjustment	*
C*					102 = Odds ratio based adjust.	*
C*									*
C* Output parameters:							*
C*	BANAM		CHAR*4		Bias adjustment name string	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/03						*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	CHARACTER*(*)	banam
C*
	REAL*8		tn, f, h, o, td, dn
C*------------------------------------------------------------------------
	iret = 0
C*
	IF ( iba .eq. 101 ) THEN
	    banam = 'DHBA'
	ELSE IF ( iba .eq. 102 ) THEN
	    banam = 'ORBA'
	ELSE
	    banam = ' '
	END IF
C*
	IF ( iba .eq. 0 ) RETURN
C*
	np = ntrpts ( itrc )
	nd = ndepth ( itrc )
	IF ( nd .ne. 4 ) THEN
	    iret = -46
	    RETURN
	END IF
	DO ip = 1, np
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
            IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +		 tn .ne. 0.0 ) THEN
		IF ( iba .eq. 101 .and. o .gt. 0.0 .and. 
     +		     f .gt. 0.0 ) THEN
C
C*		    Fedor Mesinger's bias correction.
C
		    h = o * ( 1. - ( ( (o-h) / o ) ** (o/f) ) )
		    f = o
		    dtrace (itrc,2,ip) = f
		    dtrace (itrc,3,ip) = h
C*
		ELSE IF ( iba .eq. 102 .and. o .gt. h .and.
     +			  f .gt. h .and. h .gt. 0 ) THEN
C
C*		    Odds ratio conservation bias correction.
C
		    td = h * ( tn - f - o + h )
		    dn = ( o - h ) * ( f - h )
		    td = td / dn
		    dn = o + .5 * ( tn / ( td - 1. ) )
		    h = dn - DSQRT ( dn * dn -
     +				   ( td * o * o ) / ( td - 1. ) )
		    f = o
		    dtrace (itrc,2,ip) = f
		    dtrace (itrc,3,ip) = h
C*
		END IF
	   END IF
	END DO
	reinit = .true.
C*
	RETURN
	END
