	SUBROUTINE RDTD_IPB ( cptyp, iret )
C************************************************************************
C* RDTD_IPB								*
C*									*
C* This subroutine initializes the probabilities needed to compute the	*
C* Panofsky-Brier Score.  These are probability values assigned to risk	*
C* categories associated with a PBS_ statistic type.			*
C*									*
C* The type of probability verification is identified by the three	*
C* characters following PBS_ in the statistic type.  These characters	*
C* are specified in CPTYP.						*
C*									*
C* If the exceeding threshold probabilities cannot be read from the	*
C* user file (pbs_XXX.prob, where XXX is the 3-char ID), then they	*
C* are set to default values based on CPTYP.  Here is the file		*
C* structure:								*
C*									*
C* HEADER RECORD - can be anything					*
C* NO_RISK_PROBABILITY     0.0						*
C* LOW_RISK		   .25						*
C* MODERATE_RISK	   .50						*
C* HIGH_RISK		  1.00						*
C*									*
C* Each data record following the header has a label string without	*
C* embedded blanks and a numerical probability value.  The records are	*
C* ordered from lowest to highest risk.					*
C*									*
C* RDTD_IPB ( CPTYP, IRET )						* 
C*									*
C* Input parameters:							*
C*	CPTYP		CHAR*3		Three-character type		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = Normal return		*
C*					-40 = invalid PBS_ type		*
C*					-41 = too many categories	*
C*									*
C* Log:									*
C* K. Brill/HPC		 6/00						*
C* K. Brill/HPC		 9/00	Changes for the simpler computation	*
C*				eliminating the use of weights		*
C************************************************************************
	INCLUDE			'rdtd.cmn'
C*
	CHARACTER*(*)		cptyp
C*
	CHARACTER*72		recrd
	CHARACTER*48		errmsg
	CHARACTER*24		carry (2)
	CHARACTER*12		filnam
	LOGICAL			exist
C------------------------------------------------------------------------
	iret = 0
C*
	filnam = 'pbs_' // cptyp (1:3) // '.prob'
	icnt = 0
	INQUIRE ( FILE = filnam, EXIST = exist, IOSTAT = ios )
	IF ( exist ) THEN
	    OPEN ( FILE = filnam, UNIT = 99, IOSTAT = ios )
	    IF ( ios .ne. 0 ) THEN
		iret = 3
		errmsg = filnam // ' not readable -- defaults used'
		CALL RDTD_ERR ( iret, errmsg, ier )
	    ELSE
C
C*		Skip past initial label record.
C
		READ ( 99, '(A)', IOSTAT = ios ) recrd
C*
		DO WHILE ( ios .eq. 0 )
		    READ ( 99, '(A)', IOSTAT = ios ) recrd
		    IF ( ios .eq. 0 ) THEN
			CALL ST_CLST ( recrd, ' ', ' ', 2,
     +				       carry, num, ier )
			IF ( ier .eq. 0 ) THEN
			    CALL ST_CRNM ( carry(2), xx, ier )
			    IF ( ier .eq. 0 .and. xx .le. 1.
     +				 .and. xx .ge. 0. ) THEN
				icnt = icnt + 1
				IF ( icnt .gt. MXPROB ) THEN
				    iret = -41
				    RETURN
				END IF
				prbwwx ( icnt ) = xx
				npbwwx = icnt
			    END IF
			END IF
		    END IF
		END DO
	    END IF
	    CLOSE ( UNIT = 99 )
	END IF
C
C*	Add new types here.  Do not exceed MXPROB.
C
C*      These are the probabilites that the threshold will
C*	be exceeded for each risk category, starting from
C*      the lowest.
C
	IF ( cptyp .eq. 'wwx' ) THEN
	    IF ( icnt .lt. 4 ) THEN
		prbwwx (1) = 0.
		prbwwx (2) = .25
		prbwwx (3) = .50
		prbwwx (4) = 1.0
		npbwwx = 4
		WRITE (6,*) ' DEFAULT WWX probabilities: '
		DO i = 1, npbwwx
		    WRITE (6,1000) i, prbwwx (i)
1000		    FORMAT ( ' Category ', I3, ' probability = ',
     +			     F5.2 )
		END DO
	    ELSE
		WRITE (6,*) ' USER DEFINED WWX probabilities: '
		DO i = 1, npbwwx
		    WRITE (6,1000) i, prbwwx (i)
		END DO
	    END IF
	ELSE
	    iret = -40
	    RETURN
	END IF
C*
	RETURN
	END
