	SUBROUTINE RDTD_LTD ( luntd, itype, iret )
C************************************************************************
C* RDTD_LTD								*
C*									*
C* This subroutine searchs the trace data file for all of the data	*
C* needed to fill the TRACES data structure.  The trace ID numbers must	*
C* have	already been stored in NTRLST.					*
C*									*
C* LUNTD is the unit number to which the trace data file is connected.	*
C*									*
C* RDTD_LTD ( LUNTD, ITYPE, IRET )					*
C*									*
C* Input parameters:							*
C*	LUNTD		INTEGER		Unit number of trace data file	*
C*	ITYPE		INTEGER		Type of plot			*
C*					  1 = time series		*
C*					  2 = scatter plot		*
C*					  3 = skill score vs thresholds	*
C*					  4 = binned categories		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-14 = invalid data hdr record	*
C*					-15 = invalid data hdr int data *
C*					-16 = error skipping trace	*
C*					-28 = not all trace data found	*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/EMC		 4/98	Remove NCELLS .eq.1 condition for call	*
C*				to RDTD_MDA				*
C* K. Brill/HPC		12/01	Change to read # of contrib records	*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	CHARACTER*256	recrd
	INTEGER		ihdr (3)
	CHARACTER*16	chdr (6)
	CHARACTER*1	crlbl, cmprs
	LOGICAL		lrcnm
C*
	CHARACTER*7	frmt
	DATA		frmt / '(F10.2)' /
C*------------------------------------------------------------------------
	iret = 0
	ios = 0
	nt = 1
	recrd = ' '
	DO WHILE ( ios .eq. 0 .and. nt .le. ntrace )
	    READ ( luntd, '(A)', IOSTAT=ios ) recrd
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( recrd, ' ', ' ', 6, chdr, num, ier )
		IF ( num .lt. 5 ) THEN
		    iret = -14
		    RETURN
		END IF
		IF ( num .eq. 6 ) THEN
		    lrcnm = .true.
		ELSE
		    lrcnm = .false.
		END IF
		CALL ST_ILST ( recrd, ' ', -99, 3, ihdr, num, ier )
		IF ( num .ne. 3 ) THEN
		    iret = -15
		    RETURN
		END IF
		it = ihdr (1)
		idpth = ihdr (2)
		npts = ihdr (3)
		crlbl = chdr (4)
		cmprs = chdr (5)
		IF ( ntrlst (nt) .eq. it ) THEN
C
C*		    Load this trace.
C
		    CALL RDTD_LOD ( luntd, itype, nt, idpth, npts,
     +				    crlbl, cmprs, lrcnm, iret )
		    IF ( iret .ne. 0 ) RETURN
		    nt = nt + 1
		ELSE
C
C*		    Skip this trace.
C
		    CALL RDTD_SKP ( luntd, npts, ier )
		    IF ( ier .ne. 0 ) THEN
			iret = -16
			RETURN
		    END IF
		END IF
	    END IF
	END DO
	nt = nt - 1
	IF ( ios .ne. 0 .or. nt .ne. ntrace ) THEN
	    iret = -28
	    RETURN
	END IF
C
C*	Now that all the traces have been read for this plot,
C*	compute the x-axis relative positions for cases when
C*	1,2,3,4,... default KMNUTS values will not work.
C
	IF ( itype .eq. 3 .or. itype .eq. 4 ) THEN
	    CALL RDTD_MDA ( .001, iret )
	    IF ( iret .ne. 0 ) RETURN
	    IF ( itype .eq. 3 ) CALL RDTD_R2C ( frmt, iret )
	END IF
C*
	RETURN
	END
