	SUBROUTINE RDTD_TRC ( itrc, icomp, lag,
     +			      rmiss, npts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_TRC								*
C*									*
C* This subroutine returns a specific trace of data.			*
C*									*
C* The traces are numbered in the order in which they are found in the	*
C* trace data file.							*
C*									*
C* ICOMP tells what value to pick off from the data field, or what	*
C* value to compute from the data field numbers:			*
C*									*
C*	ICOMP			Action					*
C*									*
C*	 -n		Return raw data for field n (undivided sum)	*
C*	 -1		Record count at all trace points		*
C*	  0		Return only CLTYP and IPTYP			*
C*	  1		Return data from field 1 = the data count	*
C*	  2		Return data from field 2 divided by count	*
C*	  3		Return data from field 3 divided by count	*
C*	n < 1000	Return data from field n divided by count	*
C*	1001		Compute BIAS from FHO values			*
C*	1002		Compute Equitable Threat Score from FHO values	*
C*	1003		Compute Critical Success Index from FHO values	*
C*	1004		Compute False Alarm Ratio from FHO values	*
C*	1005		Compute Postagreement from FHO values		*
C*	1006		Compute Prefigurance from FHO values		*
C*	1007		Compute Probability of Detection from FHO values*
C*	1008		Compute Threat Score from FHO values		*
C*	1009		Cumulative Forecast Prcp Vol % vs Thrshld	*
C*	1010		Cumulative Correctly Frcst Prcp Vol % vs Thrshld*
C*	1011		Cumulative Observed Prcp Vol % vs Thrshld	*
C*	1012		Forecast Prcp Vol % of Ttl vs Thrshld		*
C*	1013		Correctly Forecast Prcp Vol % of Ttl vs Thrshld	*
C*	1014		Observed Prcp Vol % of Ttl vs Thrshld           *
C*	1015		Forecast Prcp # % of Ttl # vs Thrshld           *
C*	1016		Correctly Forecast Prcp # % of Ttl # vs Thrshld *     
C*	1017		Observed Prcp # % of Ttl # vs Thrshld		*
C*	1018		Forecast # % of Ttl <= Thrshld vs Thrshld	*
C*	1019		Correctly Frcst # % of Ttl <= Thrshld vs Thrshld*
C*	1020		Observed # % of Ttl <= Thrshld # vs Thrshld	*
C*	1021		Compute False Alarm Rate (f-h)/(N-o)		*
C*	1022		Compute Conditional Miss Rate (o-h)/(N-f)	*
C*	1023		Compute Heidke Skill Score			*
C*	1024		Compute	Peirce-Hanssen-Kuipers Skill Score	*
C*	1025		Compute ODDS RATIO				*
C*	1026		Compute log of ODDS RATIO			*
C*	1027		Compute standard error of log of ODDS RATIO	*
C*	1028		Compute ODDS RATIO Skill Score			*
C*	1029		Compute ODDS RATIO Skill Score Cubed		*
C*	1030		Compute log (ODDS RATIO) / STD ERROR of same	*
C*	1031		Area between ODDS RATIO ROC & chance ROC curves	*
C*									*
C*  Any of the preceding 10xx series may be computed from bias adjusted	*
C*  FHO values.  To do this, precede the 10xx code number with one of	*
C*  the following bias adjustment specification prefixes:		*
C*									*
C*	101		Fedor Mesinger's dH/dF bias adjustment		*
C*	102		Conservation of Odds Ratio bias adjustment	*
C*									*
C*	-------		-------						*
C*	1101		Compute BIAS (SAL1L2, SL1L2)			*
C*	1102		Compute RMS error (SAL1L2, SL1L2)		*
C*	1103		Compute Correlation (SAL1L2, SL1L2)		*
C*	1104		Compute Covariance (SAL1L2,SL1L2)		*
C*	1105		Compute Forecast Variance (SAL1L2, SL1L2)	*
C*	1106		Compute Observation Variance (SAL1L2, SL1L2)	*
C*	1107		Compute Forecast Std Dev (SAL1L2, SL1L2)	*
C*	1108		Compute Obs Std Dev (SAL1L2, SL1L2)		*
C*	1109		Compute Error Std Dev (SAL1L2, SL1L2)		*
C*	1110		Compute BIAS + Error Std Dev (SAL1L2, SL1L2)	*
C*	1111		Compute BIAS - Error Std Dev (SAL1L2, SL1L2)	*
C*	1112		Compute BIAS**2					*
C*	1113		Compute -2*Covariance				*
C*	1114		Compute Error Variance				*
C*	1115		Compute Mean Squared Error			*
C*									*
C*	1201		Compute speed BIAS (VAL1L2, VL1L2)		*
C*	1202		Compute vector RMS error (VAL1L2, VL1L2)	*
C*	1203		Compute vector Correlation (VAL1L2, VL1L2)	*
C*	1204		Compute vector Covariance (VAL1L2,VL1L2)	*
C*	1205		Compute vector Forecast Variance (VAL1L2, VL1L2)*
C*	1206		Compute vector Obs Variance (VAL1L2, VL1L2)	*
C*	1207		Compute vector Forecast Std Dev (VAL1L2, VL1L2)	*
C*	1208		Compute vector Obs Std Dev (VAL1L2, VL1L2)	*
C*	1209		Compute U comp BIAS (VAL1L2, VL1L2)		*
C*	1210		Compute V comp BIAS (VAL1L2, VL1L2)		*
C*	1211		Compute vector BIAS magnitude (VAL1L2, VL1L2)	*
C*	1212		Compute vector Error Std Dev (VAL1L2, VL1L2)	*
C*	1213		Compute vector BIAS**2				*
C*	1214		Compute -2 * (vector Covariance)		*
C*	1215		Compute vector Error Variance			*
C*	1216		Compute vector Mean Squared Error		*
C*									*
C*	1301		Compute Panofsky-Brier Score for PBS_WWX stat	*
C*	1302		Compute frequency of observation exceeding	*
C*			  threshold for	the no risk category		*
C*	1303		Compute frequency of observation exceeding	*
C*			  threshold for	the low risk category		*
C*	1304		Compute frequency of observation exceeding	*
C*			  threshold for	the moderate risk category	*
C*	1305		Compute frequency of observation exceeding	*
C*			  threshold for	the high risk category		*
C*	1306		Compute target Brier Score for PBS_WWX stat	*
C*            For low + moderate + high risk categories:		*
C*	1307		Compute BIAS Score from PBS values		*
C*	1308		Compute Equitable Threat Score from PBS values	*
C*	1309		Compute Critical Success Index from PBS values	*
C*	1310		Compute False Alarm Ratio from PBS values	*
C*	1311		Compute Postagreement from PBS values		*
C*	1312		Compute Prefigurance from PBS values		*
C*	1313		Compute Probability of Detection from PBS values*
C*	1314		Compute Threat Score from PBS values		*
C*            For moderate + high risk categories:			*
C*	1315		Compute BIAS Score from PBS values		*
C*	1316		Compute Equitable Threat Score from PBS values	*
C*	1317		Compute Critical Success Index from PBS values	*
C*	1318		Compute False Alarm Ratio from PBS values	*
C*	1319		Compute Postagreement from PBS values		*
C*	1320		Compute Prefigurance from PBS values		*
C*	1321		Compute Probability of Detection from PBS values*
C*	1322		Compute Threat Score from PBS values		*
C*            For high risk category:					*
C*	1323		Compute BIAS Score from PBS values		*
C*	1324		Compute Equitable Threat Score from PBS values	*
C*	1325		Compute Critical Success Index from PBS values	*
C*	1326		Compute False Alarm Ratio from PBS values	*
C*	1327		Compute Postagreement from PBS values		*
C*	1328		Compute Prefigurance from PBS values		*
C*	1329		Compute Probability of Detection from PBS values*
C*	1330		Compute Threat Score from PBS values		*
C*            Overall sums:						*
C*	1331		Total number in forecast risk areas (2+3+4)*N 	*
C*	1332		Total number > threshold (5+6+7+8)*N		*
C*            For low + moderate + high risk categories:		*
C*	1333		Compute Heidke Skill Score from PBS values		*
C*	1334		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1335		Compute ODDS RATIO				*
C*	1336		Compute log of ODDS RATIO			*
C*	1337		Compute Standard Error of log of ODDS RATIO	*
C*	1338		Compute ODDS RATIO Skill Score			*
C*	1339		Compute ODDS RATIO Skill Score Cubed		*
C*            For moderate + high risk categories:			*
C*	1340		Compute Heidke Skill Score from PBS values	*
C*	1341		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1342		Compute ODDS RATIO				*
C*	1343		Compute log of ODDS RATIO			*
C*	1344		Compute Standard Error of log of ODDS RATIO	*
C*	1345		Compute ODDS RATIO Skill Score			*
C*	1346		Compute ODDS RATIO Skill Score Cubed		*
C*            For high risk category:					*
C*	1347		Compute Heidke Skill Score from PBS values	*
C*	1348		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1349		Compute ODDS RATIO				*
C*	1350		Compute log of ODDS RATIO			*
C*	1351		Compute Standard Error of log of ODDS RATIO	*
C*	1352		Compute ODDS RATIO Skill Score			*
C*	1353		Compute ODDS RATIO Skill Score Cubed		*
C*									*
C*      1401            Forecast variance weighted PE			*
C*      1402		Analysis variance weighted PE			*
C*      1403		Forecast variance fraction weighted PE		*
C*      1404		Analysis variance fraction weighted PE		*
C*      1405            Forecast variance fraction			*
C*	1406		Analysis variance fraction			*
C*	1407		Forecast amplitude				*
C*									*
C*	1500		Brier score from BS records			*
C*	150x		Compute average forecast probability for	*
C*			events occurring in category x			*
C*	155x		Compute observed frequency for category x	*
C*									*
C*	9001		Compute count as fraction of total along trace	*
C*									*
C* XPTS is an array of real valued relative plotting positions for	*
C* the points on this trace.  If IPTYP = 1 or 2, XPTS is the time in	*
C* days from the earliest time in the entire plot.  Otherwise,	XPTS	*
C* gives the relative position of the data values as positive integer	*
C* values.								*
C*									*
C* CLTYP determines whether the labels are character or real type.	*
C* If CLTYP = r, the labels are real; if CLTYP = c, the labels are 	*
C* character.  If CLTYP = t, the labels are character time stamps.	*
C*									*
C* If LAG > 0, then the value at a data point on a trace becomes the	*
C* combination of that trace point's values with those of the preceding	*
C* LAG-1 trace points.							*
C*									*
C* The missing value flag is RMISS on return.				*
C*									*
C* Note that TRCDAT is a REAL*8 array.					*
C*									*
C* RDTD_TRC ( ITRC, ICOMP, LAG, RMISS, NPTS, XPTS, TRCDAT, XMIN, XMAX,	*
C*	      TRCMIN, TRCMAX, CLBL, RLBL, CLTYP, IPTYP, PRMNAM,		*
C*	      PRFCT, IRET )						*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number			*
C*	ICOMP		INTEGER		Computational code number	*
C*	LAG		INTEGER		Intra-trace data combo lag	*
C*	RMISS		REAL		Missing value			*
C*									*
C* Input and output parameter:						*
C*	NPTS		INTEGER		Input: maximum # of trace points*
C*					Output: actual number		*
C*									*
C* Output parameters:							*
C*	XPTS   (NPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (NPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (NPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (NPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*					+02 = all trc pnts missing	*
C*				 	  0 = normal return 		*
C*					-29 = cannot compute stats	*
C*					-30 = data field not present	*
C*					-31 = NPTS too small for trace	*
C*					-32 = invalid ICOMP code	*
C*					-36 = data depth too small	*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/98	Added PRMNAM				*
C* K. Brill/EMC		 4/98	Return computed parm name only		*
C* K. Brill/EMC		 4/98	Check LTAXIS				*
C* K. Brill/EMC		 6/98	Assign TRCDAT in order of sorted labels *
C* K. Brill/EMC		 6/98	Fill t series gaps with missing values	*
C* K. Brill/EMC		 1/99	Add intra-trace data combination (LAG)	*
C* K. Brill/HPC		 2/00	+2 return for all trace points missing	*
C* K. Brill/HPC		 8/00	Changes for PBS_WWX, PHSE stats, % prcp	*
C*				volume vs threshold			*
C* K. Brill/HPC		 9/00	Added target Brier score, code 1306	*
C* K. Brill/HPC		12/00	Compute skill scores from PBS #s	*
C* K. Brill/HPC		 3/01	Add codes 1015--1020			*
C* K. Brill/HPC		 7/01	Add codes 1331 and 1332			*
C* K. Brill/HPC		12/01	Added codes 1109--1115, 1211--1216	*
C* K. Brill/HPC		12/01	Change to read # of contrib records	*
C* K. Brill/HPC		 6/02	Add CALL CPB_GSCR for code 1500; add	*
C*				call to CPB_GAFP for 1501+; add call to	*
C*				CPB_GOBP for 1551+			*
C* K. Brill/HPC		10/02	Added codes 1021-29; 1333-1353		*
C* K. Brill/HPC		12/02	Added code 9001				*
C* K. Brill/HPC		 2/03	Set the perfect forecast value; read	*
C*				PRMNAM from a .lst file			*
C* K. Brill/HPC		 3/03	Added code 1030				*
C* K. Brill/HPC		 5/03	Get stat name from ind var if blank	*
C* K. Brill/HPC		 6/03	Add BIAS adjustment capability		*
C* K. Brill/HPC		 8/03	Added code 1031				*
C************************************************************************
	INCLUDE		'rdtd.cmn'
	PARAMETER	( TOLRNC = .00005 )
C*
	REAL*8		trcdat (*)
	REAL		rlbl (*), xpts (*)
	CHARACTER*(*)	clbl (*), cltyp, prmnam
C*
	CHARACTER*24	qclbl, cstat, parts (4)
	CHARACTER*32	stfil
	CHARACTER*5	cpren
	CHARACTER*4	banam
	CHARACTER*1	ccat
	REAL*8		trcdum (MXDPTS)
	REAL		trcsav (MXDPTS)
	REAL*8		td
	LOGICAL		fhoflg, found, exist
C*------------------------------------------------------------------------
	iret = 0
	prfct = rmiss
	iptyp = iptype
	cltyp = lbltyp
	IF ( icomp .eq. 0 ) RETURN
	IF ( ntrpts (itrc) .gt. npts ) THEN
	    iret = -31
	    RETURN
	ELSE
	    mxpts = npts
	    npts = ntrpts (itrc)
	END IF
	IF ( icombo (itrc) .lt. 0 ) THEN
	    iret = -32
	    RETURN
	END IF
	DO i = 1, MXDPTS
	    trcdat (i) = rmiss
	END DO
C
C*	Re-initialize trace data if necessary.
C
	CALL RDTD_REI ( ier )
C
C*	Do intra-trace data combination.
C
	CALL RDTD_LAG ( lag, itrc, ier )
C*
	IF ( statnm (itrc) .ne. ' ' ) THEN
	    cstat = statnm (itrc)
	ELSE
	    cstat = stativ
	END IF
C
C*	Check for BIAS adjustment.
C
	fhoflg = ( INDEX ( cstat, 'FHO' ) .gt. 0 )
	IF ( fhoflg .and. ( icomp .gt.  1000000 .or.
     +			    icomp .lt. -1000000 ) ) THEN
	    IF ( icomp .lt. 0 ) THEN
		isgn = -1
		icomp = -icomp
	    ELSE
		isgn = 1
	    END IF
C
C*	    Detect bias adjustment specification prefix.
C
	    iba = INT ( icomp / 10000 )
	    icmp = icomp - iba * 10000
	    icmp = isgn * icmp
	ELSE
	    icmp = icomp
	    iba = 0
	END IF
C*
	CALL RDTD_BAJ ( itrc, iba, banam, iret )
C*
	IF ( iret .ne. 0 ) RETURN
	prmnam = parmnm (itrc)
	indx = 0
	trcmax = -1.E30
	trcmin = 1.E30
	ncats = ndepth (itrc) / 3
	max15 = 1500 + ncats
	mx155 = 1550 + ncats
	IF ( icmp .gt. 1000 .and. icmp .le. 1031 ) THEN
	    IF ( .not. fhoflg .or. ndepth (itrc) .lt. 4 ) THEN
		iret = -29
		RETURN
	    END IF
	    IF ( icmp .eq. 1001 ) THEN
		CALL CS_BSSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BIAS_SCORE'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1002 ) THEN
		CALL CS_ETSK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'EQ_THT_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1003 .or. icmp .eq. 1008 ) THEN
		CALL CS_TSSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'CSI=THRTSC'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1004 ) THEN
		CALL CS_FASK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FLS_ALRM_RATIO'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1005 ) THEN
		CALL CS_PASK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'POSTAGREMT'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1006 .or. icmp .eq. 1007 ) THEN
		CALL CS_PDSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'PREFIG=POD'
		prfct = 1.
		IF ( icmp .eq. 1007 ) prmnam = 'PROB_OF_DET'
	    ELSE IF ( icmp .eq. 1009 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1010 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1011 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1012 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1013 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1014 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1015 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1016 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1017 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1018 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1019 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1020 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1021 ) THEN
		CALL CS_FASK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FLS_ALRM_RATE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1022 ) THEN
		CALL CS_FASK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'COND_MSS_RATE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1023 ) THEN
		CALL CS_ETSK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'HEIDKE_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1024 ) THEN
		CALL CS_ETSK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'P-H-K_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1025 ) THEN
		CALL CS_ORSK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1026 ) THEN
		CALL CS_ORSK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'LOG_ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1027 ) THEN
		CALL CS_ORSK ( 3, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'STDERR_LOG(OR)'
	    ELSE IF ( icmp .eq. 1028 ) THEN
		CALL CS_ORSK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RTO_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1029 ) THEN
		CALL CS_ORSK ( 4, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RTO_SKSC**3'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1030 ) THEN
		CALL CS_ORSK ( 5, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'LN_OR/STDV_LN_OR'
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1031 ) THEN
		CALL CS_ORSK ( 6, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ROC_AREA-CHANCE'
		prfct = .5
	    END IF
	ELSE IF ( icmp .gt. 1100 .and. icmp .le. 1115 ) THEN
	    IF ( ndepth (itrc) .lt. 6 ) THEN
		iret = -36
		RETURN
	    END IF
	    IF ( icmp .eq. 1101 ) THEN
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1102 ) THEN
		CALL CS_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_RMSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1103 ) THEN
		CALL CS_CORR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_CORR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1104 ) THEN
		CALL CS_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1105 ) THEN
		CALL CS_FVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_FRVAR'
	    ELSE IF ( icmp .eq. 1106 ) THEN
		CALL CS_OVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_OBVAR'
	    ELSE IF ( icmp .eq. 1107 ) THEN
		CALL CS_FSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_FRSDV'
	    ELSE IF ( icmp .eq. 1108 ) THEN
		CALL CS_OSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_OBSDV'
	    ELSE IF ( icmp .eq. 1109 ) THEN
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_ERROR_SIG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1110 .or.
     +		      icmp .eq. 1111 ) THEN
		IF ( icmp .eq. 1110 ) THEN
		    sign = 1.0
		    prmnam = 'SCLR_BIAS+ERRSIG'
		ELSE
		    sign = -1.0
		    prmnam = 'SCLR_BIAS-ERRSIG'
		END IF
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		DO ip = 1, ntrpts (itrc)
		    trcsav (ip) = trcdum (ip)
		END DO
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss .and.
     +			 trcsav (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcsav (ip) + sign * trcdum (ip)
			IF ( trcdum (ip) .gt. trcmax )
     +			    trcmax = trcdum (ip)
			IF ( trcdum (ip) .lt. trcmin )
     +			    trcmin = trcdum (ip)
		    ELSE
			trcdum (ip) = rmiss
		    END IF
		END DO
	    ELSE IF ( icmp .eq. 1112 ) THEN
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'SCALR_BIAS**2'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1113 ) THEN
		CALL CS_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		END IF
		prmnam = '-2*SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1114 ) THEN
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'SCLR_ERROR_VAR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1115 ) THEN
		CALL CS_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'SCALR_MSE'
		prfct = 0.0
	    END IF
	ELSE IF ( icmp .gt. 1200 .and. icmp .le. 1216 ) THEN
	    IF ( ndepth (itrc) .lt. 8 ) THEN
		iret = -36
		RETURN
	    END IF
	    IF ( icmp .eq. 1201 ) THEN
		CALL CV_BIAS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_SPD_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1202 ) THEN
		CALL CV_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_RMSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1203 ) THEN
		CALL CV_CORR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_CORR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1204 ) THEN
		CALL CV_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_COVAR'
	    ELSE IF ( icmp .eq. 1205 ) THEN
		CALL CV_FVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_FRVAR'
	    ELSE IF ( icmp .eq. 1206 ) THEN
		CALL CV_OVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_OBVAR'
	    ELSE IF ( icmp .eq. 1207 ) THEN
		CALL CV_FSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_FRSDV'
	    ELSE IF ( icmp .eq. 1208 ) THEN
		CALL CV_OSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_OBSDV'
	    ELSE IF ( icmp .eq. 1209 ) THEN
		CALL CS_BIAS ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'U-CMP_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1210 ) THEN
		CALL CS_BIAS ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'V-CMP_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1211 ) THEN
		CALL CV_VBIS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_BIAS_MAG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1212 ) THEN
		CALL CV_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_ERROR_SIG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1213 ) THEN
		CALL CV_VBIS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VECTR_BIAS**2'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1214 ) THEN
		CALL CV_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		END IF
		prmnam = '-2*VCTR_COVAR'
	    ELSE IF ( icmp .eq. 1215 ) THEN
		CALL CV_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VCTR_ERROR_VAR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1216 ) THEN
		CALL CV_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VECTR_MSE'
		prfct = 0.0
	    END IF
	ELSE IF ( icmp .gt. 1300 .and. icmp .le. 1306 ) THEN
	    IF ( icmp .eq. 1301 ) THEN
		CALL CPB_SCR ( 0, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx, npbwwx,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BRIER_SCORE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1306 ) THEN
		CALL CPB_SCR ( 1, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx, npbwwx,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'TARGET_BRIER_SCR'
	    ELSE
C
C*		Compute codes 1302--1305.
C
		nrisk = icmp - 1301
		CALL CPB_FRQ ( MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss, nrisk,
     +			       trcdum, trcmin, trcmax, iret )
		IF ( nrisk .eq. 1 ) THEN
		    prmnam = 'NO_RISK_PRB'
		ELSE IF ( nrisk .eq. 2 ) THEN
		    prmnam = 'LOW_RISK_PRB'
		ELSE IF ( nrisk .eq. 3 ) THEN
		    prmnam = 'MOD_RISK_PRB'
		ELSE IF ( nrisk .eq. 4 ) THEN
		    prmnam = 'HI_RISK_PRB'
		END IF
	    END IF
	    IF ( iret .ne. 0 ) THEN
		iret = iret - 41
		RETURN
	    END IF
	ELSE IF ( icmp .ge. 1307 .and. icmp .le. 1353 ) THEN
C
C*	    Compute skill scores using the PBS numbers.
C
	    IF ( icmp .lt. 1315 .or. ( icmp .ge. 1333 .and.
     +		 icmp .le. 1339 ) ) THEN
		icat = 1
		cpren = 'LOW+_'
	    ELSE IF ( icmp .lt. 1323 .or. ( icmp .ge. 1340 .and.
     +		      icmp .le. 1346 ) ) THEN
		icat = 2
		cpren = 'MOD+_'
	    ELSE IF ( icmp .lt. 1331 .or. ( icmp .ge. 1347 .and.
     +		      icmp .le. 1353 ) ) THEN
		icat = 3
		cpren = 'HIGH_'
	    END IF
	    ndp = ndepth (itrc)
	    IF ( icmp .eq. 1307 .or. icmp .eq. 1315 .or.
     +		 icmp .eq. 1323 ) THEN
		CALL CPB_BSSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'BIAS_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1308 .or. icmp .eq. 1316 .or.
     +		      icmp .eq. 1324 ) THEN
		CALL CPB_ETSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'EQ_THT_SCR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1309 .or. icmp .eq. 1317 .or.
     +		      icmp .eq. 1325 ) THEN
		CALL CPB_FASK ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'FLS_ALR_RAT'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1310 .or. icmp .eq. 1318 .or.
     +		      icmp .eq. 1326 ) THEN
		CALL CPB_FASK ( 0, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'FLS_ALR_RTO'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1311 .or. icmp .eq. 1319 .or.
     +		      icmp .eq. 1327 ) THEN
		CALL CPB_PASK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'POSTAGREMT'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1312 .or. icmp .eq. 1313 .or.
     +		      icmp .eq. 1320 .or. icmp .eq. 1321 .or.
     +		      icmp .eq. 1328 .or. icmp .eq. 1329 ) THEN
		CALL CPB_PDSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'POD=PREFIG'
		prfct = 1.0
		IF ( icmp .eq. 1313 .or. icmp .eq. 1321 .or.
     +		     icmp .eq. 1329 ) prmnam = cpren // 'PROB_OF_DET'
	    ELSE IF ( icmp .eq. 1314 .or. icmp .eq. 1322 .or.
     +		      icmp .eq. 1330 ) THEN
		CALL CPB_TSSK ( 0, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'CSI=THRTSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1331 ) THEN
		CALL CPB_SUMS ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, 1,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'SUM_IN_RISK_AREA'
	    ELSE IF ( icmp .eq. 1332 ) THEN
		CALL CPB_SUMS ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, 2,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'SUM > THRESHOLD'
	    ELSE IF ( icmp .eq. 1333 .or. icmp .eq. 1340 .or.
     +		      icmp .eq. 1347 ) THEN
		CALL CPB_TSSK ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'HEIDKE_SKSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1334 .or. icmp .eq. 1341 .or.
     +		      icmp .eq. 1348 ) THEN
		CALL CPB_TSSK ( 2, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'P-H-K_SKSCR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1335 .or. icmp .eq. 1342 .or.
     +		      icmp .eq. 1349 ) THEN
		CALL CPB_TSSK ( 4, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1336 .or. icmp .eq. 1343 .or.
     +		      icmp .eq. 1350 ) THEN
		CALL CPB_TSSK ( 6, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'LN(ODS_RTO)'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1337 .or. icmp .eq. 1344 .or.
     +		      icmp .eq. 1351 ) THEN
		CALL CPB_TSSK ( 3, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'STDERR_LNOR'
	    ELSE IF ( icmp .eq. 1338 .or. icmp .eq. 1345 .or.
     +		      icmp .eq. 1352 ) THEN
		CALL CPB_TSSK ( 5, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODSRTO_SKSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1339 .or. icmp .eq. 1346 .or.
     +		      icmp .eq. 1353 ) THEN
		CALL CPB_TSSK ( 7, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODDS_RSS**3'
		prfct = 1.0
	    END IF
C*
	ELSE IF ( icmp .gt. 1400 .and. icmp .le. 1407 ) THEN
	    IF ( icmp .eq. 1401 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 4, 5,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'AC_FORVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1401 ) THEN
C
C*		For time series, divide each weighted element
C*		by the mean of the weights.
C
		CALL RDTD_EST ( itrc, rmiss, 4, kpts, trcdum,
     +				trcmin, trcmax, iret )
		IF ( iret .lt. 0 ) RETURN
		CALL RDTD_AFW ( 2, itrc, rmiss, 5, ntrpts (itrc),
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'TS_FORVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1402 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 6, 7,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'AC_ANLVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1402 ) THEN
C
C*		For time series, divide each weighted element
C*		by the mean of the weights.
C
		CALL RDTD_EST ( itrc, rmiss, 6, kpts, trcdum,
     +				trcmin, trcmax, iret )
		IF ( iret .lt. 0 ) RETURN
		CALL RDTD_AFW ( 2, itrc, rmiss, 7, ntrpts (itrc),
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'TS_ANLVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1403 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 4, 10,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FORVARFRC_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1404 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 6, 11,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ANLVARFRC_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1405 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 5, 10,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FOR_VARIANCE_FRC'
	    ELSE IF ( icmp .eq. 1406 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 7, 11,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ANL_VARIANCE_FRC'
	    ELSE IF ( icmp .eq. 1407 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 1, 3, 9,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FORCST_AMPLITUDE'
	    END IF
	ELSE IF ( icmp .ge. 1500 .and. icmp .le. max15 ) THEN
	    IF ( icmp .eq. 1500 ) THEN
		CALL CPB_GSCR ( MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'BRIER_SCORE'
		prfct = 0.
	    END IF
	    IF ( icmp .gt. 1500 ) THEN
		ncat = icmp - 1500
		CALL CPB_GAFP ( ncat, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		WRITE (ccat,'(I1)') ncat
		prmnam = 'AVG_FR_PRB|OB_C' // ccat
	    END IF
	ELSE IF ( icmp .gt. max15 .and. icmp .le. mx155 ) THEN
	    ncat = icmp - 1550
	    CALL CPB_GOBP ( ncat, MXTRCS, MXDPTH, ndepth (itrc),
     +			    ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    WRITE (ccat,'(I1)') ncat
	    prmnam = 'OBSVD_FREQ_CAT_' // ccat
	ELSE IF ( icmp .eq. 9001 ) THEN
	    CALL RDTD_CFT ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    prmnam = 'CNT_FRAC_TRC_TTL'
	ELSE IF ( icmp .gt. 1000 ) THEN
	    iret = -32
	    RETURN
	ELSE IF ( icmp .eq. -1 ) THEN
	    DO ip = 1, ntrpts (itrc)
		IF ( drecnm (itrc,ip) .ge. 0 ) THEN
		    trcdum (ip) = drecnm (itrc,ip)
		    IF ( trcdum (ip) .gt. trcmax )
     +			trcmax = trcdum (ip)
		    IF ( trcdum (ip) .lt. trcmin )
     +			trcmin = trcdum (ip)
		ELSE
		    trcdum (ip) = rmiss
		END IF
	    END DO
	ELSE IF ( icmp .lt. -1 .or. icmp .eq. 1 ) THEN
	    CALL RDTD_EST ( itrc, rmiss, icmp, kpts, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	ELSE
	    CALL RDTD_EST ( itrc, rmiss, icmp, kpts, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	END IF
C
C*	Set default trace labels.  Check for file with list
C*      of labels.
C
	CALL ST_CLST ( cstat, '_', 'x', 4, parts, npr, ier )
	IF ( npr .gt. 0 ) THEN
	    CALL ST_RNAN ( parts (npr), qclbl, lls, iret )
	    ispc = INDEX ( qclbl, ' ' ) - 1
	    qclbl = qclbl (1:ispc) // '.lst'
	    IF ( npr .gt. 1 ) THEN
		DO ipr = 1, npr-1
		    IF ( ipr .eq. 1 ) THEN
			stfil = parts (ipr)
		    ELSE
			CALL ST_LSTR ( stfil, lls, ier )
			lls = lls + 1
			stfil (lls:) = parts (ipr)
		    END IF
		END DO
		CALL ST_LSTR ( stfil, lls, ier )
		lls = lls + 1
		stfil (lls:) = qclbl
	    ELSE
		stfil = qclbl
	    END IF
	    INQUIRE ( FILE = stfil, EXIST = exist )
	    IF ( exist ) THEN
	        OPEN ( FILE = stfil, UNIT=99, IOSTAT=ios )
	        exist = ( ios .eq. 0 )
	    END IF
	ELSE
	    exist = .false.
	END IF
	IF ( indx .eq. 1 ) THEN
	    prmnam = 'DATA_COUNT'
	ELSE IF ( indx .gt. 1 .and. exist ) THEN
	    ii = 0
	    im1 = indx - 1
	    DO WHILE ( ii .lt. im1 .and. ios .eq. 0 )
		ii = ii + 1
		READ ( 99, '(A)', IOSTAT=ios ) stfil
		IF ( ii .eq. im1 ) THEN
		    CALL ST_CLST ( stfil, ' ', ' ', 2, parts, npr, ier )
		    prmnam = parts (1)
		    IF ( npr .gt. 1 ) THEN
			CALL ST_CRNM ( parts (2), prfct, ier )
		    ELSE
			prfct = rmiss
		    END IF
		END IF
	    END DO
	    IF ( ios .ne. 0 ) THEN
		prmnam = 'UNDEFINED_PARM'
	    END IF
	    CLOSE ( UNIT=99 )
	ELSE IF ( indx .gt. 1 ) THEN
	    isl1l2 = INDEX ( cstat, 'SAL1L2' ) +
     +		     INDEX ( cstat, 'SL1L2' )  +
     +		     INDEX ( cstat, 'SSAL1L2' )
	    ivl1l2 = INDEX ( cstat, 'VAL1L2' ) +
     +		     INDEX ( cstat, 'VL1L2' )  +
     +		     INDEX ( cstat, 'VSAL1L2' )
	    ifho   = INDEX ( cstat, 'FHO' )
	    ipbsn  = INDEX ( cstat, 'PBS_WWX' )
	    iphse  = INDEX ( cstat, 'PHSE' )
	    ivlck  = INDEX ( cstat, 'VLCEK' )
	    igbs   = INDEX ( cstat, 'GBS' )
	    IF ( isl1l2 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'F_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'O_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'FO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'F2_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'O2_MEAN'
	    ELSE IF ( ivl1l2 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'UF_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'VF_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'UO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'VO_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'F.O_MEAN'
		IF ( indx .eq. 7 ) prmnam = 'F.F_MEAN'
		IF ( indx .eq. 8 ) prmnam = 'O.O_MEAN'
	    ELSE IF ( ifho .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'FRCST'
		IF ( indx .eq. 3 ) prmnam = 'HITS'
		IF ( indx .eq. 4 ) prmnam = 'OBSRVD'
	    ELSE IF ( ivlck .ne. 0 ) THEN
		IF ( indx .ge. 2 .and.
     +		     indx .le. 5 ) prfct = 0.
		IF ( indx .eq. 2 ) prmnam = 'S1'
		IF ( indx .eq. 3 ) prmnam = 'BIAS'
		IF ( indx .eq. 4 ) prmnam = 'ERROR_SD'
		IF ( indx .eq. 5 ) prmnam = 'RMS_ERROR'
		IF ( indx .eq. 6 ) prmnam = 'OBS_AVG'
		IF ( indx .eq. 7 ) prmnam = 'OBS_SD'
	    ELSE IF ( ipbsn .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'EVNT_FRC_LO_RISK'
		IF ( indx .eq. 3 ) prmnam = 'EVNT_FRC_MD_RISK'
		IF ( indx .eq. 4 ) prmnam = 'EVNT_FRC_HI_RISK'
		IF ( indx .eq. 5 ) prmnam = 'EVNTFRC>TH_NORSK'
		IF ( indx .eq. 6 ) prmnam = 'EVNTFRC>TH_LORSK'
		IF ( indx .eq. 7 ) prmnam = 'EVNTFRC>TH_MDRSK'
		IF ( indx .eq. 8 ) prmnam = 'EVNTFRC>TH_HIRSK'
	    ELSE IF ( iphse .ne. 0 ) THEN
		IF ( ( indx .ge. 2 .and. indx .le. 4 )
     +            .or. indx .eq. 6 ) prfct = 0.
		IF ( indx .eq. 2 ) prmnam = 'PHASE_ERROR'
		IF ( indx .eq. 3 ) prmnam = 'AMPLITUDE_ERROR'
		IF ( indx .eq. 4 ) prmnam = 'FORVAR*PHS_ERROR'
		IF ( indx .eq. 5 ) prmnam = 'FORVAR_CONTRIB'
		IF ( indx .eq. 6 ) prmnam = 'ANLVAR*PHS_ERROR'
		IF ( indx .eq. 7 ) prmnam = 'ANLVAR_CONTRIB'
		IF ( indx .eq. 8 ) prmnam = 'ANALY_PHSANG'
		IF ( indx .eq. 9 ) prmnam = 'ANALY_AMPLTD'
		IF ( indx .eq. 10 ) prmnam = 'TTLFOR_VARIANCE'
		IF ( indx .eq. 11 ) prmnam = 'TTLANL_VARIANCE'
	    ELSE IF ( igbs .ne. 0 ) THEN
		ncat = ( indx - 1 ) / 3 + 1
		IF ( MOD ( (indx-1), 3 ) .eq. 0 ) ncat = ncat - 1
		WRITE (ccat,'(I1)') ncat
		IF ( MOD ( indx, 3 ) .eq. 2 )
     +		    prmnam = 'MN_FR_PRB*OBS_C' // ccat
		IF ( MOD ( indx, 3 ) .eq. 0 )
     +		    prmnam = 'MN(FR_PRB**2)_C' // ccat
		IF ( MOD ( indx, 3 ) .eq. 1 )
     +		    prmnam = 'FRACTION_OBSD_C' // ccat
	    ELSE
		prmnam = 'UNDEFINED_PARM'
	    END IF
	END IF
C
C*	Place bias adjustment string before name, truncating
C*      string at left end.
C
	IF ( banam .ne. ' ' ) THEN
	    prmnam = banam // '_' // prmnam
	END IF
C
C*	Scan for all missing values.
C
	icnt = 0
	DO ip = 1, npts
	    IF ( trcdum (ip) .eq. rmiss ) icnt = icnt + 1
	END DO
	IF ( icnt .eq. npts ) THEN
	    iret = +2
	END IF
C
C*	Do x-axis values.
C
	xmax = -1.E30
	xmin = 1.E30
	IF ( iptyp .eq. 1 .or. iptyp .eq. 2 ) THEN
	    DO ip = 1, npts
		td = FLOAT ( kmnuts (itrc,ip) ) / 1440.D00
		IF ( td .gt. xmax ) xmax = td
		IF ( td .lt. xmin ) xmin = td
		xpts (ip) = td
		trcdat (ip) = trcdum (ip)
	    END DO
	    IF ( iptyp .eq. 1 ) THEN
		CALL RDTD_MVL ( itrc, rmiss, mxpts, xpts, trcdat, npts,
     +				rlbl, clbl, ier )
		IF ( ier .ne. 0 ) iret = ier
		RETURN
	    END IF
	ELSE
	    npts = npntrs
	    DO ip = 1, npts
		xpts (ip)= ip
	    END DO
	    it = itrc
	    IF ( lbltyp .eq. 'r' ) THEN
		DO ip = 1, ntrpts (it)
		    qlbl = xrlbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( ABS ( xrlbls (1,kpntrs(i)) - qlbl )
     +				.lt. TOLRNC ) THEN
			    td = FLOAT ( i )
			    IF ( td .gt. xmax ) xmax = td
			    IF ( td .lt. xmin ) xmin = td
			    xpts (i) = td
			    trcdat (i) = trcdum (ip)
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	    ELSE
		DO ip = 1, ntrpts (it)
		    qclbl = xclbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( xclbls (1,kpntrs(i)) .eq. qclbl ) THEN
			    td = FLOAT ( i )
			    IF ( td .gt. xmax ) xmax = td
			    IF ( td .lt. xmin ) xmin = td
			    xpts (i) = td
			    trcdat (i) = trcdum (ip)
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	    END IF
	END IF
C*	
	IF ( cltyp .eq. 'r' .and. ltaxis ) THEN
	    DO ip = 1, npts
		rlbl (ip) = xrlbls (itrc,ip)
		clbl (ip) = ' '
	    END DO
	ELSE IF ( ltaxis ) THEN
	    DO ip = 1, npts
		rlbl (ip) = rmiss
		clbl (ip) = xclbls (itrc,ip)
	    END DO
	ELSE IF ( cltyp .eq. 'r' .and. .not. ltaxis ) THEN
	    DO ip = 1, npntrs
		rlbl (ip) = xrlbls (1,kpntrs(ip))
		clbl (ip) = ' '
	    END DO
	ELSE IF ( .not. ltaxis ) THEN
	    DO ip = 1, npntrs
		rlbl (ip) = rmiss
		clbl (ip) = xclbls (1,kpntrs(ip))
	    END DO
	END IF
C
C*	Compute % or accumulated % for ICOMP = 1009--1017.
C
	IF ( icmp .ge. 1009 .and. icmp .le. 1011 ) THEN
	    CALL CS_ACCM ( 1, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1012 .and. icmp .le. 1014 ) THEN
	    CALL CS_ACCM ( 0, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1015 .and. icmp .le. 1017 ) THEN
	    CALL CS_PCBC ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1018 .and. icmp .le. 1020 ) THEN
	    CALL CS_RPBT ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
C*
	RETURN
	END
